# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with_jdk6 1
%define with_repolib 1

%if %with_repolib
%define repodir %{_javadir}/repository.jboss.com/jacorb/%{version}jboss.patch6-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src
%endif

Name:          jacorb
Version:       2.3.0
Release:       %mkrel 2
Summary:       The free Java implementation of the OMG's CORBA standard
Group:         Development/Java
License:       LGPL
Url:           http://www.jacorb.org/
Source0:       http://www.jacorb.org/releases/2.3.0/JacORB-2.3.0-src.zip
Source1:       jacorb-jboss-component-info.xml
Source2:       http://repository.jboss.com/jacorb/2.3.0jboss.patch3/resources/jacorb.properties
Source3:       http://repository.jboss.com/jacorb/2.3.0jboss.patch3/resources/orb.idl
Source4:       jacorb-repolib-README
Source5:       jacorb-idl-compiler.pom
Source6:       jacorb-2.3.0.pom
Patch0:        jacorb-2.3.0-notification-build_xml.patch
Patch1:        jacorb-2.3.0-version.patch
# The size of a chunk should not include any bytes of padding that might have
# been added after the chunk for alignment purposes. This patch allows JacORB
# to interoperate with the ORB in Sun's JDK 1.5 with chunking of custom RMI
# valuetypes enabled (jacorb.interop.chunk_custom_rmi_valuetypes=on), as it
# should be per the CORBA spec.
Patch2:        jacorb-2.3.0-chunk_size.patch
# In handle_chunking: change to distinguish a null value tag from
# a chunk size tag (the latter must be positive).
# In read_untyped_value and readChunkSizeTag: changes for correctness (to
# ensure that chunk_end_pos is set to -1 if we are not within a chunk) and
# for clarity.
Patch3:        jacorb-2.3.0-null_value_tag.patch
# Fix for bug #782 in JacORB's bugzilla system:
# The creation of an SSLServerSocket fails when JacORB 2.3.0 uses the JSSE
# included in Sun's JDK 1.4 and later releases. The problem is in the wrapper
# class JSSEUtil, which causes an IllegalAccessException to be thrown.
Patch4:        jacorb-2.3.0-JSSE.patch
# Fix for bug #783 in JacORB's bugzilla system:
# Server throws CORBA.INTERNAL (ArrayIndexOutOfBoundsException) when a client
# uses an IOR with a component tagged with TAG_CSI_SEC_MECH_LIST. When the
# current implementation of the method
# org.jacorb.orb.iiop.IIOPProfile.getTLSPortFromCSIComponent finds an IOR
# component that is tagged with TAG_CSI_SEC_MECH_LIST and has a non-empty list
# of security mechanisms, it assumes that the first mechanism listed has a
# transport component tagged with TAG_TLS_SEC_TRANS. It tries to access the
# data of the presumed TLS_SEC_TRANS component, without first checking the
# component's tag. If this tag is TAG_NULL_TAG rather than TAG_TLS_SEC_TRANS,
# then an ArrayIndexOutOfBoundsException occurs.
Patch5:        jacorb-2.3.0-IIOP.patch
# Fix for NPE on shutdown
Patch6:        jacorb-2.3.0-IIOP_Shutdown.patch
# This patch resets the port of the primary address to zero when an
# IORInterceptor adds a TAG_CSI_SEC_MECH_LIST component with transport
# protection requirements (SSL), as it should be per the CSI v2 specification.
Patch7:        jacorb-2.3.0-primaddress_port.patch
# The SSL profile check is unnecessary and incorrect, as it should also check
# for the presence of the TAG_TLS_SEC_TRANS tag in the IIOPProfile.
# By not doing so, it causes JacORB not to open SSL connections when the
# server-side IORs contain only the TAG_TLS_SEC_TRANS tag. We can just
# eliminate this verification since the remaining method body already performs
# the necessary checks correctly.
Patch8:        jacorb-2.3.0-ssl_verification.patch
Patch9:        jacorb-2.3.0-manifest-classpath.patch
Patch10:       jacorb-jdk6.patch
Patch11:       jacorb-2.3.0-javadoc-maxmemory.patch
# JBPAPP-1477 JacORB 2.3.0.jboss5 intermittently hangs during shutdown.
# Thread dump shows it waiting in RequestController.waitForShutdown(),
# presumably beacause it believes there are outstanding requests still
# in progress.
Patch12:       jacorb-2.3.0-CORBA_OBJECT_NOT_EXIST.patch
# This patch removes the OTS classes
Patch13:       jacorb-2.3.0-remove_ots_classes.patch
# read_boolean() now only adjusts positions if the chunk_end_pos == pos,
# no longer calling handle_chunking(). The problem with handle_chunking()
# is that it aligns the current position and this can cause CDRInputStream
# to "skip" valid boolean values, as those are not padded.
Patch14:       jacorb-2.3.0-read_boolean.patch


BuildRequires: java-devel >= 0:1.6.0
BuildRequires: jpackage-utils
BuildRequires: ant
BuildRequires: antlr
BuildRequires: apache-commons-collections
BuildRequires: apache-commons-logging
BuildRequires: avalon-framework
BuildRequires: avalon-logkit
BuildRequires: backport-util-concurrent
BuildRequires: concurrent
BuildRequires: picocontainer
BuildRequires: tanukiwrapper
BuildRequires: xdoclet
BuildRequires: xjavadoc
BuildRequires: java_cup
Requires:      antlr
Requires:      apache-commons-collections
Requires:      apache-commons-logging
Requires:      avalon-framework
Requires:      avalon-logkit
Requires:      backport-util-concurrent
Requires:      concurrent
Requires:      java >= 0:1.6.0
Requires:      jpackage-utils
Requires:      mx4j
Requires:      picocontainer
Requires:      tanukiwrapper
Requires:      java_cup
BuildArch:     noarch

%description
The free Java implementation of the OMG's CORBA standard.

JacORB Features

* high-performance, fully multithreaded ORB
* 100% pure Java, JDK 1.3 and 1.4 compatible, also cooperates with Sun's JDK 1.2 classes
  (releases prior to 1.4 are compatible with JDK 1.1)
* IDL compiler, supports OMG IDL/Java language mapping rev. 2.3, OBV
* native IIOP, GIOP 1.2 and Bidirectional GIOP
* POA (Portable Object Adapter)
* AMI (Asynchronous Method Invocation)
* Quality of Service Policies (QoS)
* ETF (Extensible Transport Framework)
* POAMonitor, a GUI tools that lets you inspect your object adapters (screenshot)
* Dynamic Invocation Interface (DII) and Dynamic Skeleton Interface (DSI)
* Dynamic Management of Anys (DynAny)
* Portable Interceptors (standard)
* OMG Interoperable Naming Service
* NameManager, a GUI browser for the name service (requires Swing or JDK 1.2) (screenshot)
* improved IIOP over SSL, includes KeyStoreManager
* OMG Notification Service and Event Service
* Transaction Service, Collection and Concurrency services
* TradingService (supports trader links), an extension of Mark Spruiell's free JTrader
* CORBA 2.3 Code set support
* OMG Data Distribution Service (DDS)
* Domain Manager, an object domain management service, includes a domain browser GUI
* Interface Repository
* IRBrowser, a GUI front end for the Interface Repository (screenshot)
* Implementation Repository
* Implementation Repository Manager, a GUI front end for the Implementation Repository
* IDL and Java source for all CORBA/COSS interfaces
* examples and full source code included

Note: To use the CORBA Notification Service add picocontainer.jar
     to the ClassPath (from the 'picocontainer' RPM).

%package manual
Group:         Development/Java
Summary:       Documents for %{name}
Requires:      %{name}-javadoc = %{version}-%{release} 

%description manual
The free Java implementation of the OMG's CORBA standard.

This package contains documents for %{name}.

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      %{name} = %{version}-%{release} 
Requires:      jpackage-utils

%description javadoc
The free Java implementation of the OMG's CORBA standard.

This package contains documentation for %{name}.

%package demo
Group:         Development/Java
Summary:       Usage examples for %{name}

%description demo
The free Java implementation of the OMG's CORBA standard.

This package contains usage examples for %{name}.

%if %with_repolib
%package repolib
Group:         Development/Java
Summary:       Artifacts to be uploaded to a repository library

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n JacORB
chmod -R go=u-w *

for j in $(find . -name "*.jar"); do
   mv $j $j.no
done
for j in $(find . -name "*.class"); do
   rm -f $j
done

%patch0 -b .sav0
%patch1 -b .sav1
%patch2 -b .sav2
%patch3 -b .sav3
%patch4 -b .sav4
%patch5 -b .sav5
%patch6 -b .sav6
%patch7 -b .sav7
%patch8 -b .sav8
%patch9 -p1 -b .sav9
%if %with_jdk6
%patch10 -p1 -b .sav10
%endif
%patch11 -p1 -b .sav11
%patch12 -b .sav12
%if 0
%patch13 -b .sav13
%endif
%patch14 -b .sav14

find . -name '*.exe' -exec rm -f '{}' \;
find . -name '*.dll' -exec rm -f '{}' \;
find . -name '*.bat' -exec rm -f '{}' \;

perl -p -i -e 's/edu(.)emory(.)mathcs(.)backport(.)java(.)util/java${1}util/' `grep edu.emory.mathcs.backport.java.util -lr *`

perl -pi -e 's/\r$//g' bin/NotifyService-Wrapper-MX4J.conf.template bin/NamingService-Wrapper.conf \
 bin/NotifyService-Wrapper.conf doc/CONTEXT_IDs doc/jacorb.css doc/Coding.txt doc/REL_NOTES \
 doc/dds/TODOLIST.txt doc/LICENSE doc/dds/style.css

pushd lib
  ln -sf $(build-classpath antlr) .
  ln -sf $(build-classpath avalon-framework-api) .
  ln -sf $(build-classpath avalon-framework-impl) .
  ln -sf $(build-classpath backport-util-concurrent) .
  ln -sf $(build-classpath avalon-logkit) .
  ln -sf $(build-classpath picocontainer) .
  ln -sf $(build-classpath tanukiwrapper) .
  pushd build
    ln -sf $(build-classpath commons-collections) .
    ln -sf $(build-classpath commons-logging) .
    ln -sf $(build-classpath java_cup) .
    ln -sf $(build-classpath xdoclet/xdoclet) .
    ln -sf $(build-classpath xdoclet/xdoclet-ejb-module) .
    ln -sf $(build-classpath xdoclet/xdoclet-jboss-module) .
    ln -sf $(build-classpath xdoclet/xdoclet-jmx-module) .
    ln -sf $(build-classpath xdoclet/xdoclet-mx4j-module) .
    ln -sf $(build-classpath xdoclet/xdoclet-web-module) .
    ln -sf $(build-classpath xjavadoc) .
  popd
popd

sed -i 's,avalon-framework-[0-9\.]\+,avalon-framework,' etc/common-xdoclet.xml

sed -i 's,@MX4J_HOME@/lib/mx4j,%{_javadir}/mx4j/mx4j,' bin/NotifyService-Wrapper-MX4J.conf.template
sed -i 's,wrapper.java.library.path.1=../lib,wrapper.java.library.path.1=%{_libdir},' bin/NotifyService-Wrapper-MX4J.conf.template
sed -i 's,wrapper.java.library.path.1=../lib,wrapper.java.library.path.1=%{_libdir},' bin/NamingService-Wrapper.conf
sed -i 's,wrapper.java.additional.3=-Djacorb.home=..,wrapper.java.additional.3=-Djacorb.home=%{_datadir}/jacorb-%{version},' bin/NotifyService-Wrapper-MX4J.conf.template
sed -i 's,wrapper.java.additional.3=-Djacorb.home=..,wrapper.java.additional.3=-Djacorb.home=%{_datadir}/jacorb-%{version},' bin/NamingService-Wrapper.conf
sed -i 's,wrapper.java.library.path.1=../lib,wrapper.java.library.path.1=%{_libdir},' bin/NotifyService-Wrapper.conf
sed -i 's,wrapper.java.additional.3=-Djacorb.home=..,wrapper.java.additional.3=-Djacorb.home=%{_datadir}/jacorb-%{version},' bin/NotifyService-Wrapper.conf
sed -i 's,-Xbootclasspath:/import/java2/jre/lib/rt.jar,-Xbootclasspath:/usr/lib/jvm/java/jre/lib/rt.jar,' bin/jacapplet
sed -i 's,$WRAPPER_HOME"/bin/wrapper","/usr/sbin/tanukiwrapper",' bin/jacorb-wrapper-common
sed -i 's,wrapper.jar,tanukiwrapper.jar,' bin/jacorb-wrapper-common
sed -i 's,WRAPPER_LIB="$WRAPPER_HOME"/lib,WRAPPER_LIB=%{_javadir},' bin/jacorb-wrapper-common
sed -i 's,#WRAPPER_CMD="/usr/local/wrapper/bin/wrapper",WRAPPER_CMD="/usr/sbin/tanukiwrapper",' bin/ntfy-wrapper.tpl
sed -i 's,#WRAPPER_HOME="/usr/local/wrapper",WRAPPER_HOME="/usr/share/java",' bin/ntfy-wrapper.tpl

pushd bin
  for i in *.tpl; do
    sed -i 's,@JACORB_HOME@,%{_datadir}/jacorb-%{version},' $i
  done
popd

%build
export JAVA_HOME=%{_jvmdir}/java-1.6.0
mkdir -p temp
export ANT_OPTS=" -Xmx256m "
export CLASSPATH=
export OPT_JAR_LIST=:
ant -Dant.build.javac.source=1.5 -Dant.build.javac.target=1.5 all doc
for i in lib/*.jar ; do j=`basename $i`; %{__cp} -p ${i} temp/${j/\.jar/_g.jar} ; done
ant -Dant.build.javac.source=1.5 -Dant.build.javac.target=1.5 realclean
ant -Dant.build.javac.source=1.5 -Dant.build.javac.target=1.5 -Ddebug=off all doc

%install
rm -rf %{buildroot}

find . -name '*.exe' -exec rm -f '{}' \;
find . -name '*.dll' -exec rm -f '{}' \;
find . -name '*.bat' -exec rm -f '{}' \;

mkdir -p %{buildroot}%{_javadir}/jacorb
install -pm 644 lib/jacorb.jar %{buildroot}%{_javadir}/jacorb/jacorb-%{version}.jar
install -pm 644 temp/jacorb_g.jar %{buildroot}%{_javadir}/jacorb/jacorb_g-%{version}.jar
install -pm 644 lib/idl.jar %{buildroot}%{_javadir}/jacorb/idl-%{version}.jar
install -pm 644 temp/idl_g.jar %{buildroot}%{_javadir}/jacorb/idl_g-%{version}.jar

mkdir -p tmp/resources
pushd tmp
  install -pm 644 ../idl/omg/CSI.idl resources/
  install -pm 644 ../idl/omg/CosTransactions.idl resources/
  install -pm 644 %{SOURCE2} resources/
  install -pm 644 %{SOURCE3} resources/
  jar -cf jacorb-resources-%{version}.jar resources
  install -pm 644 jacorb-resources-%{version}.jar %{buildroot}%{_javadir}/jacorb/resources-%{version}.jar
  %add_to_maven_depmap jacorb resources %{version} JPP/jacorb resources
popd
rm -rf tmp

(
  cd %{buildroot}%{_javadir}/jacorb
  for jar in *-%{version}*; do 
    ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`
  done
)

mkdir -p %{buildroot}%{_mavenpomdir}
install -pm 644 %{SOURCE5} %{buildroot}%{_mavenpomdir}/JPP.jacorb-idl.pom
%add_to_maven_depmap jacorb jacorb-idl-compiler %{version} JPP/jacorb idl
%add_to_maven_depmap org.jacorb jacorb-idl-compiler %{version} JPP/jacorb idl
install -pm 644 %{SOURCE6} %{buildroot}%{_mavenpomdir}/JPP.jacorb-jacorb.pom
%add_to_maven_depmap jacorb jacorb %{version} JPP/jacorb jacorb
%add_to_maven_depmap org.jacorb jacorb %{version} JPP/jacorb jacorb

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/jacorb-%{version}/bin
install -pm 755 bin/jaco  %{buildroot}%{_bindir}/jaco
sed -i 's,${JACORB_HOME}/lib/idl.jar:${JACORB_HOME}/lib/logkit-1.2.jar,/usr/share/jacorb-2.3.0/lib/idl.jar:/usr/share/jacorb-2.3.0/lib/logkit-1.2.jar,' bin/idl
install -pm 755 bin/idl  %{buildroot}%{_bindir}/idl

rm -rf bin/jaco bin/idl
cp -pr bin/*  %{buildroot}%{_datadir}/jacorb-%{version}/bin
pushd %{buildroot}%{_bindir}
  ln -sf ../../../bin/jaco %{buildroot}%{_datadir}/%{name}-%{version}/bin/jaco
  ln -sf ../../../bin/idl %{buildroot}%{_datadir}/%{name}-%{version}/bin/idl
popd

cp -pr bin/* %{buildroot}%{_datadir}/%{name}-%{version}/bin
mkdir -p %{buildroot}%{_datadir}/%{name}-%{version}/etc
cp -pr etc/* %{buildroot}%{_datadir}/%{name}-%{version}/etc
mkdir -p %{buildroot}%{_datadir}/%{name}-%{version}/idl
cp -pr idl/* %{buildroot}%{_datadir}/%{name}-%{version}/idl

mkdir -p %{buildroot}%{_datadir}/%{name}-%{version}/lib
pushd %{buildroot}%{_datadir}/%{name}-%{version}/lib
  ln -sf ../../java/jacorb/jacorb-%{version}.jar jacorb.jar
  ln -sf ../../java/jacorb/idl-%{version}.jar idl.jar
  ln -sf $(build-classpath tanukiwrapper) wrapper-3.1.0.jar
  ln -sf $(build-classpath backport-util-concurrent) backport-util-concurrent.jar
  ln -sf $(build-classpath antlr) antlr-2.7.2.jar
  ln -sf $(build-classpath avalon-framework-api) .
  ln -sf $(build-classpath avalon-framework-impl) .
  ln -sf $(build-classpath picocontainer) picocontainer-1.2.jar
  ln -sf $(build-classpath avalon-logkit) logkit-1.2.jar
  ln -sf $(build-classpath concurrent) .
popd

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr doc/api/* %{buildroot}%{_javadocdir}/%{name}
rm -rf doc/api
ln -sf %{_javadocdir}/%{name} doc/api

mkdir -p %{buildroot}%{_datadir}/%{name}-%{version}/demo
cp -pr demo/* %{buildroot}%{_datadir}/%{name}-%{version}/demo

%if %with_repolib
mkdir -p %{buildroot}%{repodir}/
mkdir -p %{buildroot}%{repodir}/resources/
mkdir -p %{buildroot}%{repodirlib}/
cp -p %{SOURCE1} %{buildroot}%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@VERSION@/%{version}jboss.patch6-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
mkdir -p %{buildroot}%{repodirsrc}/
cp -p %{PATCH0} %{buildroot}%{repodirsrc}/
cp -p %{PATCH1} %{buildroot}%{repodirsrc}/
cp -p %{PATCH2} %{buildroot}%{repodirsrc}/
cp -p %{PATCH3} %{buildroot}%{repodirsrc}/
cp -p %{PATCH4} %{buildroot}%{repodirsrc}/
cp -p %{PATCH5} %{buildroot}%{repodirsrc}/
cp -p %{PATCH6} %{buildroot}%{repodirsrc}/
cp -p %{PATCH7} %{buildroot}%{repodirsrc}/
cp -p %{PATCH8} %{buildroot}%{repodirsrc}/
cp -p %{PATCH10} %{buildroot}%{repodirsrc}/
cp -p %{PATCH11} %{buildroot}%{repodirsrc}/
cp -p %{PATCH12} %{buildroot}%{repodirsrc}/
cp -p %{SOURCE0} %{buildroot}%{repodirsrc}/
cp -p %{SOURCE4} %{buildroot}%{repodirsrc}/README
cp -p %{SOURCE0} %{buildroot}%{repodirlib}/
cp -p idl/omg/CSI.idl %{buildroot}%{repodir}/resources/CSI.idl
cp -p idl/omg/CosTransactions.idl %{buildroot}%{repodir}/resources/CosTransactions.idl
cp -p %{SOURCE2} %{buildroot}%{repodir}/resources/jacorb.properties
cp -p %{SOURCE3} %{buildroot}%{repodir}/resources/orb.idl
cp -p %{buildroot}%{_javadir}/jacorb/idl_g.jar %{buildroot}%{repodirlib}/idl_g.jar
cp -p %{buildroot}%{_javadir}/jacorb/jacorb_g.jar %{buildroot}%{repodirlib}/jacorb_g.jar
cp -p %{buildroot}%{_javadir}/jacorb/jacorb.jar %{buildroot}%{repodirlib}/jacorb.jar
cp -p %{buildroot}%{_javadir}/jacorb/idl.jar %{buildroot}%{repodirlib}/idl.jar
cp -p %{buildroot}%{_mavenpomdir}/JPP.jacorb-idl.pom %{buildroot}%{repodirlib}/idl.pom
%endif

pushd %{buildroot}%{_datadir}/%{name}-%{version}/bin
  chmod 644 *.conf
  for i in *.template; do
    cat $i | sed -e 's,@JACORB_HOME@,%{_datadir}/%{name}-%{version},' > `echo $i | sed -e 's,.template$,,'`
  done
popd


%files
%defattr(-,root,root) 
%{_javadir}/jacorb/idl-%{version}.jar
%{_javadir}/jacorb/idl.jar
%{_javadir}/jacorb/jacorb-%{version}.jar
%{_javadir}/jacorb/jacorb.jar
%{_javadir}/jacorb/idl_g-%{version}.jar
%{_javadir}/jacorb/idl_g.jar
%{_javadir}/jacorb/jacorb_g-%{version}.jar
%{_javadir}/jacorb/jacorb_g.jar
%{_javadir}/jacorb/resources-%{version}.jar
%{_javadir}/jacorb/resources.jar
%dir %{_datadir}/jacorb-%{version}/
%attr(755,root,root) %{_bindir}/jaco
%attr(755,root,root) %{_bindir}/idl
%attr(755,root,root) %{_datadir}/jacorb-%{version}/bin/*
%{_datadir}/jacorb-%{version}/etc
%{_datadir}/jacorb-%{version}/idl
%{_datadir}/jacorb-%{version}/lib
%dir %{_datadir}/jacorb-%{version}/demo
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc doc/LICENSE

%pre javadoc
[ $1 -gt 1 ] && [ -L %{_javadocdir}/%{name} ] && \
rm -rf $(readlink -f %{_javadocdir}/%{name}) %{_javadocdir}/%{name} || :

%files javadoc
%{_javadocdir}/%{name}

%files manual
%doc index.html doc

%files demo
%{_datadir}/jacorb-%{version}/demo

%if %with_repolib
%files repolib
%defattr(-,root,root) 
%{_javadir}/repository.jboss.com
%endif



%changelog

* Mon Feb 06 2012 gil <gil> 2.3.0-2.mga2
+ Revision: 205401
- build fix
  added jacorb-2.3.0.pom
- imported package jacorb

  + dmorgan <dmorgan>
    - Fix groups
    - Fix pom install
    - Fix pom install
    - Fix classpath ( from gil)
    - Fix BuildRequires
    - Clean spec file


* Sun Jun 26 2011 gil <gil> 2.3.0-0.%%mkrel
- initial rpm